@@ -2,28 +2,28 @@
 #'
 #' @description Adds zeros for catches of species that were not captured in a sampling event but were captured in at least one other sampling event (i.e., adds zeros to the data frame for capture events where a species was not observed).
 #'
-#' @details The data frame in \code{df} must contain a column that identifies a unique capture event (given in \code{eventvar}), a column with the name for the species captured (given in \code{specvar}), and a column that contains the number of that species captured (potentially given to \code{zerovar}; see details).  All sampling event and species combinations where catch information does not exist is identified and a new data frame that contains a zero for the catch for all of these combinations is created.  This new data frame is appended to the original data frame to construct a data frame that contains complete catch information -- i.e., including zeros for species in events where that species was not captured.
+#' @details The data frame in \code{df} must contain a column that identifies a unique capture event (given in \code{eventvar}), a column with the name for the species captured (given in \code{specvar}), and a column that contains the number of that species captured (potentially given to \code{zerovar}; see details). All sampling event and species combinations where catch information does not exist is identified and a new data frame that contains a zero for the catch for all of these combinations is created. This new data frame is appended to the original data frame to construct a data frame that contains complete catch information -- i.e., including zeros for species in events where that species was not captured.
 #'
-#' The data frame may contain other information related to the catch, such as number of recaptured fish, number of fish released, etc.  These additional variables can be included in \code{zerovar} so that zeros will be added to these variables as well (e.g., if the catch of the species is zero, then the number of recaptures must also be zero).  All variables not given in \code{eventvar}, \code{specvar}, or \code{zerovar} will be assumed to be related to \code{eventvar} and \code{specvar} (e.g., date, gear type, and habitat) and, thus, will be repeated with these variables.
+#' The data frame may contain other information related to the catch, such as number of recaptured fish, number of fish released, etc. These additional variables can be included in \code{zerovar} so that zeros will be added to these variables as well (e.g., if the catch of the species is zero, then the number of recaptures must also be zero). All variables not given in \code{eventvar}, \code{specvar}, or \code{zerovar} will be assumed to be related to \code{eventvar} and \code{specvar} (e.g., date, gear type, and habitat) and, thus, will be repeated with these variables.
 #' 
-#' In situations where no fish were captured in some events, the \code{df} may contain rows that have a value for \code{eventvar} but not for \code{specvar}.  These rows are important because zeros need to be added for each observed species for these events.  However, in these situations, a \code{<NA>} species will appear in the resulting data.frame.  It is unlikely that these \dQuote{missing} species are needed so they will be removed if \code{na.rm=TRUE} (default) is used.
+#' In situations where no fish were captured in some events, the \code{df} may contain rows that have a value for \code{eventvar} but not for \code{specvar}. These rows are important because zeros need to be added for each observed species for these events. However, in these situations, a \code{<NA>} species will appear in the resulting data.frame. It is unlikely that these \dQuote{missing} species are needed so they will be removed if \code{na.rm=TRUE} (default) is used.
 #' 
-#' One should test the results of this function by creating a frequency table of the \code{eventvar} or \code{specvar}.  In either case, the table should contain the same value in each cell of the table.  See the examples.
+#' One should test the results of this function by creating a frequency table of the \code{eventvar} or \code{specvar}. In either case, the table should contain the same value in each cell of the table. See the examples.
 #'
-#' @note An error will be returned if either \code{specvar} or \code{eventvar} are factors with any \code{NA} levels.  This usually arises if the dataframe was subsetted/filtered prior to using \code{addZeroCatch}.  See \code{\link{filterD}} or \code{\link[base]{droplevels}} for descriptions of how to drop unused levels.
+#' @note An error will be returned if either \code{specvar} or \code{eventvar} are factors with any \code{NA} levels. This usually arises if the dataframe was subsetted/filtered prior to using \code{addZeroCatch}. See \code{\link{filterD}} or \code{\link[base]{droplevels}} for descriptions of how to drop unused levels.
 #' 
 #' @param df A data frame that contains the capture summary data as described in the details.
 #' @param eventvar A string for the variable that identifies unique capture events.
 #' @param specvar A string for the variable that identifies the species captured.
-#' @param zerovar A string or vector of strings for the variable(s) that should be set equal to zero.  See details.
-#' @param na.rm A logical that indicates if rows of df that are \code{NA} should be removed after adding the zeros.  See details.
+#' @param zerovar A string or vector of strings for the variable(s) that should be set equal to zero. See details.
+#' @param na.rm A logical that indicates if rows of df that are \code{NA} should be removed after adding the zeros. See details.
 #' @return A data frame with the same structure as \code{df} but with rows of zero observation data appended.
 #' 
 #' @author Derek H. Ogle, \email{derek@@derekogle.com}
 #'
 #' @section IFAR Chapter: 2-Basic Data Manipulations
 #'
-#' @references Ogle, D.H.  2016.  \href{http://derekogle.com/IFAR}{Introductory Fisheries Analyses with R}.  Chapman & Hall/CRC, Boca Raton, FL.
+#' @references Ogle, D.H. 2016. \href{http://derekogle.com/IFAR}{Introductory Fisheries Analyses with R}. Chapman & Hall/CRC, Boca Raton, FL.
 #' 
 #' @keywords manip
 #'
@@ -113,7 +113,7 @@ addZeroCatch <- function(df,eventvar,specvar,zerovar,na.rm=TRUE) {
   ## Handle multiple specvar variables
   multSpec <- FALSE
   if (length(specvar)>1) {
-    multSpec=TRUE
+    multSpec <- TRUE
     # allow converting back to factors later if only two variables
     if (length(specvar)==2) {
       lvls1 <- lvls2 <- NULL
@@ -143,7 +143,7 @@ addZeroCatch <- function(df,eventvar,specvar,zerovar,na.rm=TRUE) {
   need0s <- tmp[which(!(all.combos %in% combos.in.df)),]
   ## Catch if there are no need for zeros, send warning, return df
   if (nrow(need0s)==0) {
-    WARN("All 'eventvar' have all species in 'specvar'; thus, there are no\nzeros to add.  The original data.frame was returned.")
+    WARN("All 'eventvar' have all species in 'specvar'; thus, there are no\nzeros to add. The original data.frame was returned.")
     df
   } else { ## Process because some zeros need to be added
     ## creates vector of names not in eventvar, specvar, or zerovar
@@ -157,20 +157,20 @@ addZeroCatch <- function(df,eventvar,specvar,zerovar,na.rm=TRUE) {
       df <- df[,c(eventvar,specvar,zerovar)]
       # prepare an empty data frame to receive zeros
       newdf <- df[FALSE,]
-      for (i in 1:nrow(need0s)) {
+      for (i in seq_len(nrow(need0s))) {
         newrow <- data.frame(need0s[i,eventvar],need0s[i,specvar],zeros)
-        newdf <- rbind(newdf,newrow)                                                              
+        newdf <- rbind(newdf,newrow)
       }    
     } else { # idvar is not empty
       # reorders columns for simplicity
       df <- df[,c(eventvar,specvar,idvar,zerovar)]
       # prepare an empty data frame to receive zeros
       newdf <- df[FALSE,]
-      for (i in 1:nrow(need0s)) {
+      for (i in seq_len(nrow(need0s))) {
         newrow <- data.frame(need0s[i,eventvar],need0s[i,specvar],
-                             unique(df[df[,eventvar]==need0s[i,eventvar],idvar]),
-                             zeros)
-        newdf <- rbind(newdf,newrow)                                                              
+                             unique(df[df[,eventvar]==need0s[i,eventvar],
+                                       idvar]),zeros)
+        newdf <- rbind(newdf,newrow)
       }
     }
     ## give newdf the same names as old (re-arranged) df
