@@ -255,4 +255,10 @@ test_that("iTypeoflm() messages and results",{
   expect_error(FSA:::iTypeoflm(glm1),"only works with")
   nl1 <- nls(mirex~B1/(1+exp(B2+B3*weight)),start=list(B1=0.4,B2=2,B3=-0.5),data=Mirex)
   expect_error(FSA:::iTypeoflm(nl1),"only works with")
+  Mirex$speciesZ <- as.character(Mirex$species)
+  Mirex$yearZ <- as.character(Mirex$year)
+  tmp <- lm(mirex~weight*speciesZ,data=Mirex)
+  expect_warning(FSA:::iTypeoflm(tmp),"variable is a 'character'")
+  tmp <- lm(mirex~yearZ*speciesZ,data=Mirex)
+  expect_warning(FSA:::iTypeoflm(tmp),"variable is a 'character'")
 })
