@@ -20,17 +20,17 @@ test_that("capHistSum() results",{
   expect_is(ch$methodB.top,"matrix")
   expect_equal(nrow(ch$methodB.top),3)
   expect_equal(ncol(ch$methodB.top),3)
-  expect_equal(colnames(ch$methodB.top),paste0("i=",1:3))
-  expect_equal(rownames(ch$methodB.top),paste0("j=",1:3))
+  expect_equal(colnames(ch$methodB.top),paste0("i=",seq_len(3)))
+  expect_equal(rownames(ch$methodB.top),paste0("j=",seq_len(3)))
   expect_is(ch$methodB.bot,"matrix")
   expect_equal(nrow(ch$methodB.bot),4)
   expect_equal(ncol(ch$methodB.bot),3)
-  expect_equal(colnames(ch$methodB.bot),paste0("i=",1:3))
+  expect_equal(colnames(ch$methodB.bot),paste0("i=",seq_len(3)))
   expect_equal(rownames(ch$methodB.bot),c("m","u","n","R"))
   expect_is(ch$m.array,"matrix")
   expect_equal(nrow(ch$m.array),3)
   expect_equal(ncol(ch$m.array),4)
-  expect_equal(rownames(ch$m.array),paste0("i=",1:3))
+  expect_equal(rownames(ch$m.array),paste0("i=",seq_len(3)))
   expect_equal(colnames(ch$m.array),c("ni","c2","c3","not recapt"))
 })  
 
@@ -60,19 +60,19 @@ test_that("capHistConvert() results",{
   expect_equal(nrow(ex1.M2I),length(unique(ex1$fish)))
   expect_equal(ncol(ex1.M2I),length(unique(ex1$yr)))
   expect_equal(sum(ex1.M2I),nrow(ex1))
-  expect_equal(names(ex1.M2I),paste0("event",1:length(unique(ex1$yr))))
+  expect_equal(names(ex1.M2I),paste0("event",seq_along(unique(ex1$yr))))
   # MARK format (with id)
   expect_is(ex1.M2I2,"data.frame")
   expect_equal(nrow(ex1.M2I2),length(unique(ex1$fish)))
   expect_equal(ncol(ex1.M2I2),length(unique(ex1$yr))+1)
   expect_equal(sum(ex1.M2I2[,2:5]),nrow(ex1))
-  expect_equal(names(ex1.M2I2),c("id",paste0("event",1:length(unique(ex1$yr)))))
+  expect_equal(names(ex1.M2I2),c("id",paste0("event",seq_along(unique(ex1$yr)))))
   # RMARK format
   expect_is(ex1.R2I,"data.frame")
   expect_equal(nrow(ex1.R2I),length(unique(ex1$fish)))
   expect_equal(ncol(ex1.R2I),length(unique(ex1$yr))+1)
   expect_equal(sum(ex1.R2I[,2:5]),nrow(ex1))
-  expect_equal(names(ex1.R2I),c("fish",paste0("event",1:length(unique(ex1$yr)))))
+  expect_equal(names(ex1.R2I),c("fish",paste0("event",seq_along(unique(ex1$yr)))))
   
   ## Frequency created from
   # event format
@@ -89,12 +89,12 @@ test_that("capHistConvert() results",{
   expect_is(ex1.M2F,"data.frame")
   expect_equal(ncol(ex1.M2F),length(unique(ex1$yr))+1)
   expect_equal(sum(ex1.M2F$freq),length(unique(ex1$fish)))
-  expect_equal(names(ex1.M2F),c(paste0("event",1:length(unique(ex1$yr))),"freq"))
+  expect_equal(names(ex1.M2F),c(paste0("event",seq_along(unique(ex1$yr))),"freq"))
   # RMark format
   expect_is(ex1.R2F,"data.frame")
   expect_equal(ncol(ex1.R2F),length(unique(ex1$yr))+1)
   expect_equal(sum(ex1.R2F$freq),length(unique(ex1$fish)))
-  expect_equal(names(ex1.R2F),c(paste0("event",1:length(unique(ex1$yr))),"freq"))
+  expect_equal(names(ex1.R2F),c(paste0("event",seq_along(unique(ex1$yr))),"freq"))
   
   ## MARK created from
   # event format
